@@ -19,16 +19,16 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE. --]]
 
 local pathsep = package.config:sub(1, 1)
-local rnc = require "rnc"
-local lfs = require "lfs"
-local TH = require "TH"
-local SDL = require "sdl"
-local runDebugger = dofile "run_debugger"
+local rnc = require("rnc")
+local lfs = require("lfs")
+local TH = require("TH")
+local SDL = require("sdl")
+local runDebugger = corsixth.require("run_debugger")
 
 -- Increment each time a savegame break would occur
 -- and add compatibility code in afterLoad functions
 
-local SAVEGAME_VERSION = 122
+local SAVEGAME_VERSION = 127
 
 class "App"
 
@@ -110,7 +110,7 @@ function App:init()
     conf_chunk(self.config)
   end
   self:fixConfig()
-  dofile "filesystem"
+  corsixth.require("filesystem")
   local good_install_folder, error_message = self:checkInstallFolder()
   self.good_install_folder = good_install_folder
   -- self:checkLanguageFile()
@@ -124,7 +124,7 @@ function App:init()
     return false, "Cannot initialise SDL"
   end
   local compile_opts = TH.GetCompileOptions()
-  local api_version = dofile "api_version"
+  local api_version = corsixth.require("api_version")
   if api_version ~= compile_opts.api_version then
     api_version = api_version or 0
     compile_opts.api_version = compile_opts.api_version or 0
@@ -153,7 +153,7 @@ function App:init()
   self.video:setBlueFilterActive(false)
   SDL.wm.setIconWin32()
 
-  self.video:setCaptureMouse(self.config.capture_mouse)
+  self:setCaptureMouse()
 
   local caption_descs = {self.video:getRendererDetails()}
   if compile_opts.jit then
@@ -168,8 +168,8 @@ function App:init()
   self.video:setCaption(self.caption)
 
   -- Prereq 2: Load and initialise the graphics subsystem
-  dofile "persistance"
-  dofile "graphics"
+  corsixth.require("persistance")
+  corsixth.require("graphics")
   self.gfx = Graphics(self)
 
   -- Put up the loading screen
@@ -212,20 +212,20 @@ function App:init()
     return math.floor(input + 0.5)
   end
   -- Load audio
-  dofile "audio"
+  corsixth.require("audio")
   self.audio = Audio(self)
   self.audio:init()
 
   -- Load movie player
-  dofile "movie_player"
+  corsixth.require("movie_player")
   self.moviePlayer = MoviePlayer(self, self.audio, self.video)
   if good_install_folder then
     self.moviePlayer:init()
   end
 
   -- Load strings before UI and before additional Lua
-  dofile "strings"
-  dofile "string_extensions"
+  corsixth.require("strings")
+  corsixth.require("string_extensions")
   self.strings = Strings(self)
   self.strings:init()
   local language_load_success = self:initLanguage()
@@ -236,17 +236,17 @@ function App:init()
   end
 
   -- Load map before world
-  dofile "map"
+  corsixth.require("map")
 
   -- Load additional Lua before world
   if good_install_folder then
     self.anims = self.gfx:loadAnimations("Data", "V")
     self.animation_manager = AnimationManager(self.anims)
     self.walls = self:loadLuaFolder("walls")
-    dofile "entity"
-    dofile "entities/humanoid"
-    dofile "entities/object"
-    dofile "entities/machine"
+    corsixth.require("entity")
+    corsixth.require("entities.humanoid")
+    corsixth.require("entities.object")
+    corsixth.require("entities.machine")
 
     local objects = self:loadLuaFolder("objects")
     self.objects = self:loadLuaFolder("objects/machines", nil, objects)
@@ -261,23 +261,23 @@ function App:init()
       Object.processTypeDefinition(v)
     end
 
-    dofile "room"
+    corsixth.require("room")
     self.rooms = self:loadLuaFolder("rooms")
 
-    dofile "humanoid_action"
+    corsixth.require("humanoid_action")
     self.humanoid_actions = self:loadLuaFolder("humanoid_actions")
 
     local diseases = self:loadLuaFolder("diseases")
     self.diseases = self:loadLuaFolder("diagnosis", nil, diseases)
 
     -- Load world before UI
-    dofile "world"
+    corsixth.require("world")
   end
 
   -- Load UI
-  dofile "ui"
+  corsixth.require("ui")
   if good_install_folder then
-    dofile "game_ui"
+    corsixth.require("game_ui")
     self.ui = UI(self, true)
   else
     self.ui = UI(self, true)
@@ -472,6 +472,12 @@ function App:loadMainMenu(message)
   end
 end
 
+--! Sets the mouse capture to the state set within
+--! app.config.capture_mouse
+function App:setCaptureMouse()
+  self.video:setCaptureMouse(self.config.capture_mouse)
+end
+
 --! Loads the first level of the specified campaign and prepares the world
 --! to be able to progress through that campaign.
 --!param campaign_file (string) Name of a CorsixTH Campaign definition Lua file.
@@ -792,7 +798,7 @@ end
 
 function App:fixConfig()
   -- Fill in default values for things which don't exist
-  local _, config_defaults = dofile "config_finder"
+  local _, config_defaults = corsixth.require("config_finder")
   for k, v in pairs(config_defaults) do
     if self.config[k] == nil then
       self.config[k] = v
@@ -1146,31 +1152,35 @@ function App:checkInstallFolder()
   -- Do a few more checks to make sure that commonly corrupted files are OK.
   local corrupt = {}
 
-  if not self.using_demo_files then
-    local function check_corrupt(path, correct_size)
-      local real_path = self.fs:getFilePath(path)
-      -- If the file exists but is smaller than usual it is probably corrupt
-      if real_path then
-        local real_size = lfs.attributes(real_path, "size")
-        if real_size + 1024 < correct_size or real_size - 1024 > correct_size then
-          corrupt[#corrupt + 1] = path .. " (Size: " .. math.floor(real_size/1024) .. " kB / Correct: about " .. math.floor(correct_size/1024) .. " kB)"
-        end
-      else
-        corrupt[#corrupt + 1] = path .. " (This file is missing)"
+  local function check_corrupt(path, correct_size)
+    local real_path = self.fs:getFilePath(path)
+    -- If the file exists but is smaller than usual it is probably corrupt
+    if real_path then
+      local real_size = lfs.attributes(real_path, "size")
+      if real_size + 1024 < correct_size or real_size - 1024 > correct_size then
+        corrupt[#corrupt + 1] = path .. " (Size: " .. math.floor(real_size/1024) .. " kB / Correct: about " .. math.floor(correct_size/1024) .. " kB)"
       end
+    else
+      corrupt[#corrupt + 1] = path .. " (This file is missing)"
     end
+  end
+  if self.using_demo_files then
+    check_corrupt("ANIMS" .. pathsep .. "WINLEVEL.SMK", 243188)
+    check_corrupt("LEVELS" .. pathsep .. "LEVEL.L1", 163948)
+    check_corrupt("DATA"  .. pathsep .. "BUTTON01.DAT", 252811)
+  else
     check_corrupt("ANIMS" .. pathsep .. "AREA01V.SMK", 251572)
     check_corrupt("ANIMS" .. pathsep .. "WINGAME.SMK", 2066656)
     check_corrupt("ANIMS" .. pathsep .. "WINLEVEL.SMK", 335220)
     check_corrupt("INTRO" .. pathsep .. "INTRO.SM4", 33616520)
     check_corrupt("QDATA" .. pathsep .. "FONT00V.DAT", 1024)
     check_corrupt("ANIMS" .. pathsep .. "LOSE1.SMK", 1009728)
+  end
 
-    if #corrupt ~= 0 then
-      table.insert(corrupt, 1, "There appears to be corrupt files in your Theme Hospital folder, " ..
-      "so don't be surprised if CorsixTH crashes. At least the following files are wrong:")
-      table.insert(corrupt, message)
-    end
+  if #corrupt ~= 0 then
+    table.insert(corrupt, 1, "There appears to be corrupt files in your Theme Hospital folder, " ..
+    "so don't be surprised if CorsixTH crashes. At least the following files are wrong:")
+    table.insert(corrupt, message)
   end
 
   return true, #corrupt ~= 0 and corrupt or nil
@@ -1254,7 +1264,7 @@ function App:loadLuaFolder(dir, no_results, append_to)
   local results = no_results and "" or (append_to or {})
   for file in lfs.dir(path) do
     if file:match("%.lua$") then
-      local status, result = pcall(dofile, dir .. file:sub(1, -5))
+      local status, result = pcall(corsixth.require, dir .. file:sub(1, -5))
       if not status then
         print("Error loading " .. dir ..  file .. ":\n" .. tostring(result))
       else
@@ -1291,8 +1301,10 @@ end
 -- a specific savegame verion is from.
 function App:getVersion(version)
   local ver = version or self.savegame_version
-  if ver > 122 then
+  if ver > 127 then
     return "Trunk"
+  elseif ver > 122 then
+    return "v0.62"
   elseif ver > 111 then
     return "v0.61"
   elseif ver > 105 then
@@ -1422,14 +1434,14 @@ function App:afterLoad()
   self.world.savegame_version = new
 
   if old < 87 then
-    local new_object = dofile "objects/gates_to_hell"
+    local new_object = corsixth.require("objects.gates_to_hell")
     Object.processTypeDefinition(new_object)
     self.objects[new_object.id] = new_object
     self.world:newObjectType(new_object)
   end
 
   if old < 114 then
-    local rathole_type = dofile "objects/rathole"
+    local rathole_type = corsixth.require("objects.rathole")
     Object.processTypeDefinition(rathole_type)
     self.objects[rathole_type.id] = rathole_type
     self.world:newObjectType(rathole_type)
@@ -1468,8 +1480,8 @@ function App:checkForUpdates()
   else
     self.lua_socket_available = true
   end
-  local http = require "socket.http"
-  local url = require "socket.url"
+  local http = require("socket.http")
+  local url = require("socket.url")
 
   print("Checking for CorsixTH updates...")
   local update_body, status, _ = http.request(update_url)
