@@ -20,7 +20,7 @@ SOFTWARE. --]]
 
 local ipairs, math_floor, unpack, select, assert
     = ipairs, math.floor, unpack, select, assert
-local TH = require "TH"
+local TH = require("TH")
 
 --! The ingame menu bar which sits (nominally hidden) at the top of the screen.
 class "UIMenuBar" (Window)
@@ -636,12 +636,21 @@ function UIMenuBar:makeGameMenu(app)
   end
   options:appendCheckItem(_S.menu_options.lock_windows, boolean_runtime_config"lock_windows")
 
+  -- Edge Scrolling
   options:appendCheckItem(_S.menu_options.edge_scrolling,
     not app.config.prevent_edge_scrolling,
     function(item) app.config.prevent_edge_scrolling = not item.checked end,
     nil,
     function() return not app.config.prevent_edge_scrolling end)
 
+  -- Mouse Capture
+  options:appendCheckItem(_S.menu_options.capture_mouse,
+    app.config.capture_mouse,
+    function(item) app.config.capture_mouse = item.checked
+      app:saveConfig()
+      app:setCaptureMouse()
+    end)
+
   options:appendCheckItem(_S.menu_options.adviser_disabled,
     not app.config.adviser_disabled,
     function(item)
@@ -775,7 +784,7 @@ function UIMenuBar:makeGameMenu(app)
         :appendCheckItem(_S.menu_debug_overlay.byte_7,      false, overlay(35, 8, 7, 7, true), "")
         :appendCheckItem(_S.menu_debug_overlay.parcel,      false, overlay("parcel"), "")
       )
-      :appendItem(_S.menu_debug.sprite_viewer, function() dofile "sprite_viewer" end)
+      :appendItem(_S.menu_debug.sprite_viewer, function() corsixth.require("sprite_viewer") end)
     )
   end
 end
