@@ -18,7 +18,7 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE. --]]
 
-local TH = require "TH"
+local TH = require("TH")
 local ipairs, math_floor
     = ipairs, math.floor
 
@@ -510,6 +510,7 @@ function UIPlaceObjects:placeObject(dont_close_if_empty)
     self.world:prepareFootprintTilesForBuild(object_footprint, self.object_cell_x, self.object_cell_y)
     real_obj = self.world:newObject(object.object.id,
         self.object_cell_x, self.object_cell_y, self.object_orientation)
+    real_obj:setState(object.state)
   end
   if room then
     room.objects[real_obj] = true
