@@ -22,17 +22,18 @@ local TH = require"TH"
 local ipairs, _G, table_remove
     = ipairs, _G, table.remove
 
-dofile "entities/patient"
-dofile "entities/staff"
-dofile "entities/vip"
-dofile "entities/grim_reaper"
-dofile "entities/inspector"
-dofile "staff_profile"
-dofile "hospital"
-dofile "epidemic"
-dofile "calls_dispatcher"
-dofile "research_department"
-dofile "entity_map"
+corsixth.require("entities.patient")
+corsixth.require("entities.staff")
+corsixth.require("entities.vip")
+corsixth.require("entities.grim_reaper")
+corsixth.require("entities.inspector")
+corsixth.require("staff_profile")
+corsixth.require("hospital")
+corsixth.require("epidemic")
+corsixth.require("calls_dispatcher")
+corsixth.require("research_department")
+corsixth.require("entity_map")
+corsixth.require("date")
 
 --! Manages entities, rooms, and the date.
 class "World"
@@ -91,14 +92,10 @@ function World:World(app)
   self.next_earthquake = { active = false }
 
   -- Time
-  self.hours_per_day = 50
   self.hours_per_tick = 1
   self.tick_rate = 3
   self.tick_timer = 0
-  self.year = 1
-  self.month = 1 -- January
-  self.day = 1
-  self.hour = 0
+  self.game_date = Date()
 
   self.room_information_dialogs_off = app.config.debug
   -- This is false when the game is paused.
@@ -179,8 +176,9 @@ function World:World(app)
   self:makeAvailableStaff(0)
   self:calculateSpawnTiles()
 
+  -- Next Events dates
   self:nextEmergency()
-  self:nextVip()
+  self.next_vip_date = self:_generateNextVipDate()
 
   -- earthquakes
   -- current_map_earthquakes is a counter that tracks which number of earthquake
@@ -473,8 +471,6 @@ local function isDiseaseUsableForNewPatient(self, disease, hospital)
   if disease.only_emergency then return false end
   if not disease.visuals_id then return true end
 
-  local current_month = (self.year - 1) * 12 + self.month
-
   -- level files can delay visuals to a given month
   -- and / or until a given number of patients have arrived
   local level_config = self.map.level_config
@@ -482,14 +478,14 @@ local function isDiseaseUsableForNewPatient(self, disease, hospital)
   local hold_visual_peep_count = level_config.gbv.HoldVisualPeepCount
 
   -- if the month is greater than either of these values then visuals will not appear in the game
-  if (hold_visual_months and hold_visual_months > current_month) or
+  if (hold_visual_months and hold_visual_months > self.game_date:monthOfGame()) or
       (hold_visual_peep_count and hold_visual_peep_count > hospital.num_visitors) then
     return false
   end
 
   -- The value against #visuals_available determines from which month a disease can appear.
   -- 0 means it can show up anytime.
-  return level_config.visuals_available[disease.visuals_id].Value < current_month
+  return level_config.visuals_available[disease.visuals_id].Value < self.game_date:monthOfGame()
 end
 
 --! Spawn a patient from a spawn point for the given hospital.
@@ -855,7 +851,7 @@ local month_length = {
 }
 
 function World:getDate()
-  return self.month, self.day
+  return self.game_date:monthOfYear(), self.game_date:dayOfMonth()
 end
 
 -- Game speeds. The second value is the number of world clicks that pass for each
@@ -871,11 +867,6 @@ local tick_rates = {
   ["Speed Up"]           = {4, 1},
 }
 
--- Return the length of the current month
-function World:getCurrentMonthLength()
-  return month_length[self.month]
-end
-
 function World:speedUp()
   self:setSpeed("Speed Up")
 end
@@ -984,35 +975,30 @@ function World:onTick()
       if not lfs.attributes(dir .. "Autosaves", "modification") then
         lfs.mkdir(dir .. "Autosaves")
       end
-      local status, err = pcall(TheApp.save, TheApp, dir .. "Autosaves" .. pathsep .. "Autosave" .. self.month .. ".sav")
+      local status, err = pcall(TheApp.save, TheApp, dir .. "Autosaves" .. pathsep .. "Autosave" .. self.game_date:monthOfYear() .. ".sav")
       if not status then
         print("Error while autosaving game: " .. err)
       end
     end
-    if self.year == 1 and self.month == 1 and self.day == 1 and self.hour == 0 then
-      if not self.ui.start_tutorial then
-        self.ui:addWindow(UIWatch(self.ui, "initial_opening"))
-        self.ui:showBriefing()
-      end
+    if self.game_date == Date() and not self.ui.start_tutorial then
+      self.ui:addWindow(UIWatch(self.ui, "initial_opening"))
+      self.ui:showBriefing()
     end
     self.tick_timer = self.tick_rate
-    self.hour = self.hour + self.hours_per_tick
 
     -- if an earthquake is supposed to be going on, call the earthquake function
     if self.next_earthquake.active then
       self:tickEarthquake()
     end
 
+    local new_game_date = self.game_date:plusHours(self.hours_per_tick)
     -- End of day/month/year
-    if self.hour >= self.hours_per_day then
+    if self.game_date:dayOfMonth() ~= new_game_date:dayOfMonth() then
       for _, hospital in ipairs(self.hospitals) do
         hospital:onEndDay()
       end
       self:onEndDay()
-      self.hour = self.hour - self.hours_per_day
-      self.day = self.day + 1
-      if self.day > month_length[self.month] then
-        self.day = month_length[self.month]
+      if self.game_date:isLastDayOfMonth() then
         for _, hospital in ipairs(self.hospitals) do
           hospital:onEndMonth()
         end
@@ -1021,27 +1007,26 @@ function World:onTick()
           -- Bail out as the game has already been ended.
           return
         end
-        self.day = 1
-        self.month = self.month + 1
-        if self.month > 12 then
-          self.month = 12
+
+        if self.game_date:isLastDayOfYear() then
           -- It is crucial that the annual report gets to initialize before onEndYear is called.
           -- Yearly statistics are reset there.
           self.ui:addWindow(UIAnnualReport(self.ui, self))
           self:onEndYear()
-          self.year = self.year + 1
-          self.month = 1
         end
       end
     end
+    self.game_date = new_game_date
+
     for i = 1, self.hours_per_tick do
       for _, hospital in ipairs(self.hospitals) do
         hospital:tick()
       end
       -- A patient might arrive to the player hospital.
       -- TODO: Multiplayer support.
-      if self.spawn_hours[self.hour + i - 1] and self.hospitals[1].opened then
-        for _ = 1, self.spawn_hours[self.hour + i - 1] do
+      local spawn_count = self.spawn_hours[self.game_date:hourOfDay() + i - 1]
+      if spawn_count and self.hospitals[1].opened then
+        for _ = 1, spawn_count do
           self:spawnPatient()
         end
       end
@@ -1053,7 +1038,7 @@ function World:onTick()
       end
       self.current_tick_entity = nil
       self.map:onTick()
-      self.map.th:updateTemperatures(outside_temperatures[self.month],
+      self.map.th:updateTemperatures(outside_temperatures[self.game_date:monthOfYear()],
           0.25 + self.hospitals[1].radiator_heat * 0.3)
       if self.ui then
         self.ui:onWorldTick()
@@ -1074,13 +1059,13 @@ function World:onTick()
 end
 
 function World:setEndMonth()
-  self.day = month_length[self.month]
-  self.hour = self.hours_per_day - 1
+  local first_day_of_next_month = Date(self.game_date:year(), self.game_date:monthOfYear() + 1)
+  self.game_date = first_day_of_next_month:plusHours(-1)
 end
 
 function World:setEndYear()
-  self.month = 12
-  self:setEndMonth()
+  local first_day_of_next_year = Date(self.game_date:year() + 1)
+  self.game_date = first_day_of_next_year:plusHours(-1)
 end
 
 -- Called immediately prior to the ingame day changing.
@@ -1096,30 +1081,29 @@ function World:onEndDay()
   self.current_tick_entity = nil
 
   --check if it's time for a VIP visit
-  if (self.year - 1) * 12 + self.month == self.next_vip_month and
-      self.day == self.next_vip_day then
+  if self.game_date:isSameDay(self.next_vip_date) then
     if #self.rooms > 0 and self.ui.hospital:hasStaffedDesk() then
       self.hospitals[1]:createVip()
     else
-      self:nextVip()
+      self.next_vip_date = self:_generateNextVipDate()
     end
   end
 
   -- check if it's time for an earthquake, and the user is at least on level 5
-  if (self.year - 1) * 12 + self.month == self.next_earthquake.start_month and
-      self.day == self.next_earthquake.start_day then
+  if self.game_date:monthOfGame() == self.next_earthquake.start_month and
+      self.game_date:dayOfMonth() == self.next_earthquake.start_day then
     -- warn the user that an earthquake is on the way
     self.next_earthquake.active = true
   end
 
   -- Maybe it's time for an emergency?
-  if (self.year - 1) * 12 + self.month == self.next_emergency_month and
-      self.day == self.next_emergency_day then
+  if self.game_date:monthOfGame() == self.next_emergency_month and
+      self.game_date:dayOfMonth() == self.next_emergency_day then
     -- Postpone it if anything clock related is already underway.
     if self.ui:getWindow(UIWatch) then
       self.next_emergency_month = self.next_emergency_month + 1
       local month_of_year = 1 + ((self.next_emergency_month - 1) % 12)
-      self.next_emergency_day = math.random(1, month_length[month_of_year])
+      self.next_emergency_day = math.random(1, Date(1, month_of_year):lastDayOfMonth())
     else
       -- Do it only for the player hospital for now. TODO: Multiplayer
       local control = self.map.level_config.emergency_control
@@ -1155,9 +1139,10 @@ function World:onEndDay()
   end
   -- Any patients tomorrow?
   self.spawn_hours = {}
-  if self.spawn_dates[self.day] then
-    for _ = 1, self.spawn_dates[self.day] do
-      local hour = math.random(1, self.hours_per_day)
+  local day = self.game_date:dayOfMonth()
+  if self.spawn_dates[day] then
+    for _ = 1, self.spawn_dates[day] do
+      local hour = math.random(1, Date.hoursPerDay())
       self.spawn_hours[hour] = self.spawn_hours[hour] and self.spawn_hours[hour] + 1 or 1
     end
   end
@@ -1183,13 +1168,13 @@ function World:onEndMonth()
   -- TODO.... this is a step closer to the way TH would check.
   -- What is missing is that if offer is declined then the next check should be
   -- either 6 months later or at the end of month 12 and then every 6 months
-  if self.month % 3 == 0 and self.month < 12 then
+  if self.game_date:monthOfYear() % 3 == 0 and self.game_date:monthOfYear() < 12 then
     self:checkIfGameWon()
   end
 
   local local_hospital = self:getLocalPlayerHospital()
   local_hospital.population = 0.25
-  if self.month >= self.map.level_config.gbv.AllocDelay then
+  if self.game_date:monthOfGame() >= self.map.level_config.gbv.AllocDelay then
     local_hospital.population = local_hospital.population * self:getReputationImpact(local_hospital)
   end
 
@@ -1197,7 +1182,7 @@ function World:onEndMonth()
   local index = 0
   local popn = self.map.level_config.popn
   while popn[index] do
-    if popn[index].Month == self.month + (self.year - 1)*12 then
+    if popn[index].Month == self.game_date:monthOfGame() then
       self.monthly_spawn_increase = popn[index].Change
       break
     end
@@ -1207,7 +1192,7 @@ function World:onEndMonth()
   self.spawn_rate = self.spawn_rate + self.monthly_spawn_increase
   self:updateSpawnDates()
 
-  self:makeAvailableStaff((self.year - 1) * 12 + self.month)
+  self:makeAvailableStaff(self.game_date:monthOfGame())
   self.autosave_next_tick = true
   for _, entity in ipairs(self.entities) do
     if entity.checkForDeadlock then
@@ -1228,7 +1213,7 @@ function World:updateSpawnDates()
   self.spawn_dates = {}
   for _ = 1, no_of_spawns do
     -- We are interested in the next month, pick days from it at random.
-    local day = math.random(1, month_length[self.month % 12 + 1])
+    local day = math.random(1, self.game_date:lastDayOfMonth())
     self.spawn_dates[day] = self.spawn_dates[day] and self.spawn_dates[day] + 1 or 1
   end
 end
@@ -1259,7 +1244,6 @@ end
 -- next emergency should look like.
 function World:nextEmergency()
   local control = self.map.level_config.emergency_control
-  local current_month = (self.year - 1) * 12 + self.month
   -- Does this level use random emergencies?
   if control and (control[0].Random or control[0].Mean) then
     -- Support standard values for mean and variance
@@ -1267,20 +1251,11 @@ function World:nextEmergency()
     local variance = control[0].Variance or 30
     -- How many days until next emergency?
     local days = math.round(math.n_random(mean, variance))
-    local next_month = self.month
+    local emergency_date = self.game_date:plusDays(days)
 
-    -- Walk forward to get the resulting month and day.
-    if days > month_length[next_month] - self.day then
-      days = days - (month_length[next_month] - self.day)
-      next_month = next_month + 1
-    end
-    while days > month_length[(next_month - 1) % 12 + 1] do
-      days = days - month_length[(next_month - 1) % 12 + 1]
-      next_month = next_month + 1
-    end
     -- Make it the same format as for "controlled" emergencies
-    self.next_emergency_month = next_month + (self.year - 1) * 12
-    self.next_emergency_day = days
+    self.next_emergency_month = emergency_date:monthOfGame()
+    self.next_emergency_day = emergency_date:dayOfMonth()
   else
     if not self.next_emergency_no then
       self.next_emergency_no = 0
@@ -1293,7 +1268,7 @@ function World:nextEmergency()
           self.next_emergency_no = self.next_emergency_no + 1
         end
       until not control[self.next_emergency_no] or
-            control[self.next_emergency_no].EndMonth >= current_month
+            control[self.next_emergency_no].EndMonth >= self.game_date:monthOfGame()
     end
 
     local emergency = control[self.next_emergency_no]
@@ -1304,14 +1279,14 @@ function World:nextEmergency()
     else
       -- Generate the next month and day the emergency should occur at.
       -- Make sure it doesn't happen in the past.
-      local start = math.max(emergency.StartMonth, self.month + (self.year - 1) * 12)
+      local start = math.max(emergency.StartMonth, self.game_date:monthOfGame())
       local next_month = math.random(start, emergency.EndMonth)
       self.next_emergency_month = next_month
       local day_start = 1
       if start == emergency.EndMonth then
-        day_start = self.day
+        day_start = self.game_date:dayOfMonth()
       end
-      local day_end = month_length[(next_month - 1) % 12 + 1]
+      local day_end = Date(1, next_month):lastDayOfMonth()
       self.next_emergency_day = math.random(day_start, day_end)
     end
   end
@@ -1319,24 +1294,17 @@ end
 
 -- Called when it is time to have another VIP
 function World:nextVip()
+  self.next_vip_date = self:_generateNextVipDate()
+end
+
+-- PRIVATE method to generate the next VIP date
+function World:_generateNextVipDate()
   -- Support standard values for mean and variance
   local mean = 180
   local variance = 30
   -- How many days until next vip?
   local days = math.round(math.n_random(mean, variance))
-  local next_month = self.month
-
-  -- Walk forward to get the resulting month and day.
-  if days > month_length[next_month] - self.day then
-    days = days - (month_length[next_month] - self.day)
-    next_month = next_month + 1
-  end
-  while days > month_length[(next_month - 1) % 12 + 1] do
-    days = days - month_length[(next_month - 1) % 12 + 1]
-    next_month = next_month + 1
-  end
-  self.next_vip_month = next_month + (self.year - 1) * 12
-  self.next_vip_day = days
+  return self.game_date:plusDays(days)
 end
 
 -- Called when it is time to have another earthquake
@@ -2104,7 +2072,7 @@ function World:objectPlaced(entity, id)
       self.ui.adviser:say(_A.room_requirements.reception_need_receptionist)
     elseif self.hospitals[1]:hasStaffOfCategory("Receptionist") and
         self.object_counts["reception_desk"] == 1 and
-        not self.hospitals[1].receptionist_msg and self.month > 3 then
+        not self.hospitals[1].receptionist_msg and self.game_date:monthOfGame() > 3 then
       self.ui.adviser:say(_A.warnings.no_desk_5)
       self.hospitals[1].receptionist_msg = true
     end
@@ -2445,8 +2413,8 @@ function World:afterLoad(old, new)
   if old < 17 then
     -- Added another object
     local pathsep = package.config:sub(1, 1)
-    local _, shield = pcall(dofile, "objects" .. pathsep .. "radiation_shield")
-    local _, shield_b = pcall(dofile, "objects" .. pathsep .. "radiation_shield_b")
+    local _, shield = pcall(corsixth.require, "objects" .. pathsep .. "radiation_shield")
+    local _, shield_b = pcall(corsixth.require, "objects" .. pathsep .. "radiation_shield_b")
     shield.slave_type = shield_b
     shield.slave_type.master_type = shield
     Object.processTypeDefinition(shield)
@@ -2601,6 +2569,11 @@ function World:afterLoad(old, new)
       end
     end
   end
+  if old < 124 then
+    self.game_date = Date(self.year, self.month, self.day, self.hour)
+    -- self.next_vip_month is number of months since the game start
+    self.next_vip_date = Date(1, self.next_vip_month, self.next_vip_day)
+  end
 
   -- Now let things inside the world react.
   for _, cat in pairs({self.hospitals, self.entities, self.rooms}) do
@@ -2730,3 +2703,7 @@ function World:isTileExclusivelyPassable(x, y, distance)
   end
   return true
 end
+
+function World:date()
+  return self.game_date:clone()
+end
